@@ -26,3 +26,5 @@ parser = argparse.ArgumentParser(add_help=False)
 parser.add_argument('--verbose', '-v', action='count')
 parser.add_argument('--version', action='version', version='%(prog)s 1')
 parser.add_argument('--format','-f', dest='format', default=DEFAULT_FMT)
+parser.add_argument('--force-login', dest='forcelogin', action="store_true",
+                    default=False)
