@@ -9,11 +9,11 @@
 # https://bitbucket.org/cfarrell1980/termine/raw/ddf534649df6/LICENSE.txt
 import logging,sys
 logger = logging.getLogger('gwiseLogger')
-logger.setLevel(logging.DEBUG)
+logger.setLevel(logging.ERROR)
 
 # create console handler and set level to debug
 ch = logging.StreamHandler( sys.__stdout__ ) # Add this
-ch.setLevel(logging.DEBUG)
+ch.setLevel(logging.ERROR)
 
 # create formatter
 formatter = logging.Formatter('%(asctime)s - %(name)s - %(levelname)s - %(message)s')
