@@ -23,3 +23,9 @@ class GWFatalException(BaseException):
 
 class GWItemFetchException(BaseException):
   pass
+
+class GWForceLoginException(BaseException):
+  pass
+  
+class GWBadArgumentException(BaseException):
+  pass
